@@ -126,7 +126,7 @@ C
 C	  WRITE(*,*)ICORR
       IF (ICORR .GE. 0) GO TO 200
 	  IFA(1)=-1
-      STOP
+C      STOP
 
 C
 C  CONSIDER EACH CONSTRAINT IN TURN, ADDING IT TO
@@ -173,7 +173,7 @@ C 225  FORMAT('0 NEW CONSTRAINT INCONSISTENT'/
 C     +' ',10E12.4,:/' ',10E12.4)
       IFA(1)=-1
       NCON=NCON-1
-      STOP
+C      STOP
 C
 C  NEW CONSTRAINT UNNECESSARY--WRITE TO OUTPUT FILE,
 C  AND DELETE THE CONSTRAINT FROM THETA
@@ -207,7 +207,7 @@ C            WRITE(*,239)
 C            WRITE(2,239)
 C 239        FORMAT('0 NUMBER OF VERTICES EXCEEDS',
 C     +      ' ROW DIMENSION OF MATRIX XVT')
-            STOP
+C            STOP
  240     CONTINUE
  250  CONTINUE
 C
@@ -238,7 +238,7 @@ C      WRITE(2,310)
 C      WRITE(*,310)
 C  310 FORMAT('0 INCONSISTENT CONSTRAINT--FATAL ERROR')
       IFA(1)=-1
-      STOP
+C      STOP
  2000 CONTINUE
 C
 C  PRINT FINAL CONSTRAINT AND DK MATRICES TO
@@ -315,14 +315,14 @@ C      WRITE(2,325) NCON
 C      WRITE(*,325) NCON
 C 325  FORMAT('0 IN CALLING ALLNR, NCM MUST BE',
 C     +' BETWEEN 1 AND NCON =',I3)
-      STOP
+C      STOP
  350  IF (NCENT .LE. N2) GO TO 360
       IFA(4)=-1
 C      WRITE(2,355)
 C      WRITE(*,355)
 C 355  FORMAT('0 NUMBER OF CENTROIDS EXCEEDS ROW',
 C     +' DIMENSION OF MATRIX CENT')
-      STOP
+C      STOP
  360  CONTINUE
 C 
 C  COMBINE COMPUTED CENTROIDS WITH VERTICES
@@ -608,19 +608,19 @@ C
       PARAMETER (N1=12,N2=1000,N3=45)
       COMMON NVAR,NVERT,NCON,THETA(N3,N1),XVT(N2,N1),
      +DK(N2,N3),IMIX,TOL1,TOL2
-      WRITE(2,10)
+C     WRITE(2,10)
   10  FORMAT('0'/' FINAL CONSTRAINT MATRIX--EACH ROW',
      +' IS A CONSTRAINT'/)
       DO 30 I=1,NCON
-         WRITE(2,20) I,(THETA(I,J),J=1,NVAR+1)
+C        WRITE(2,20) I,(THETA(I,J),J=1,NVAR+1)
   20     FORMAT(' ',I4,2X,10E12.4,:/' ',6X,10E12.4)
   30  CONTINUE
-      WRITE(2,40)
+C      WRITE(2,40)
   40  FORMAT('0'/' FINAL DK MATRIX (# VERTICES BY',
      +' # CONSTRAINTS)'/'   DK(I,J) = 0 INDICATES',
      +' THAT VERTEX I IS ON CONSTRAINT PLANE J'/)
       DO 60 I=1,NVERT
-         WRITE(2,50) I,(DK(I,J),J=1,NCON)
+C        WRITE(2,50) I,(DK(I,J),J=1,NCON)
   50     FORMAT(' ',I4,10E12.4,:/' ',
      +   4(4X,10E12.4,:/' '))
   60  CONTINUE
